@@ -184,7 +184,7 @@ make_geom = function(geom,
   args_to_syms = syms(names(args_to_defaults))
   names(args_to_syms) = names(args_to_defaults)
 
-  new_function(
+  new_f = new_function(
     c(
       pairlist2(
         mapping = mapping,
@@ -224,6 +224,9 @@ make_geom = function(geom,
     }),
     env = parent.frame()
   )
+  attr(body(new_f), "srcref") = NULL
+
+  new_f
 }
 
 
