@@ -4,7 +4,7 @@
 ###############################################################################
 
 library(dplyr)
-
+library(distributional)
 
 
 
@@ -41,13 +41,13 @@ test_that("lkjcorr_marginal throws an error for invalid K", {
 })
 
 test_that("marginalize_lkjcorr works", {
-  ref = data.frame(
+  ref = as.data.frame(tibble(
     coef = c("a", "b"),
     prior = c("lkjcorr(3)", "lkjcorr(3)" ),
     .dist = c("lkjcorr_marginal", "lkjcorr_marginal"),
-    stringsAsFactors = FALSE
-  )
-  ref$.args = list(list(2, 3), list(4, 3))
+    .args = list(list(2, 3), list(4, 3)),
+    .dist_obj = dist_wrap(dist = "lkjcorr_marginal", c(2, 4), c(3, 3), package = "ggdist"),
+  ))
 
   expect_equal(
     data.frame(coef = c("a", "b"), prior = "lkjcorr(3)", stringsAsFactors = FALSE) %>%
